@@ -163,7 +163,7 @@ class Logging:
         self.n_fibers = 300
         self.dome_flat_shape = np.zeros((imax1, imax2), dtype=np.int64)
         if self.args.legacy_aptest:
-            master_path = (Path(apogee_data.__file__).absolute().parent.parent.parent
+            master_path = (Path(apogee_data.__file__).absolute().parent.parent
                            / 'dat/utr_master_flat_21180043.npy')
             self.ap_master_all = np.load(master_path.as_posix())
             # Cut and paste from aptest, don't ask how it works
@@ -194,7 +194,7 @@ class Logging:
 
         else:
             master_path = (Path(
-                apogee_data.__file__).absolute().parent.parent.parent
+                apogee_data.__file__).absolute().parent.parent
                            / 'dat/master_dome_flat_1.npy')
             master_data = np.load(master_path.as_posix())
             self.ap_master = np.average(master_data[:, 900:910], axis=1)
